@@ -54,6 +54,9 @@
 
 using namespace std;
 
+#define XMT_FILT_LEN 256
+#define QSK_DELAY_LEN 4*XMT_FILT_LEN
+
 const cw::SOM_TABLE cw::som_table[] = {
 	/* Prosigns */
 	{'=',	"<BT>",   {1.0,  0.33,  0.33,  0.33, 1.0,   0, 0}	}, // 0
@@ -182,10 +185,14 @@ void cw::tx_init(SoundBase *sc)
 	phaseacc = 0;
 	lastsym = 0;
 	qskphase = 0;
+	if (progdefaults.pretone) pretone();
 
 	symbols = 0;
 	acc_symbols = 0;
 	ovhd_symbols = 0;
+
+	cw_xmt_filter->create_filter(lwr, upr);
+	qsk_ptr = XMT_FILT_LEN / 2;
 }
 
 void cw::rx_init()
@@ -233,6 +240,7 @@ cw::~cw() {
 	if (hilbert) delete hilbert;
 	if (cw_FIR_filter) delete cw_FIR_filter;
 	if (cw_FFT_filter) delete cw_FFT_filter;
+	if (cw_xmt_filter) delete cw_xmt_filter;
 	if (bitfilter) delete bitfilter;
 	if (trackingfilter) delete trackingfilter;
 }
@@ -308,6 +316,23 @@ cw::cw() : modem()
 	FilterFFTLen = 4096;
 	cw_FFT_filter = new fftfilt(progdefaults.CWspeed/(1.2 * samplerate), FilterFFTLen);
 
+// transmit filtering
+
+	nbfreq = frequency;
+	nbpf = progdefaults.CW_bpf;
+	lwr = nbfreq - nbpf/2.0;
+	upr = nbfreq + nbpf/2.0;
+	if (lwr < 50.0) lwr = 50.0;
+	if (upr > 3900.0) upr = 3900.0;
+	lwr /= samplerate;
+	upr /= samplerate;
+	xmt_signal = new double[XMT_FILT_LEN];
+	for (int i = 0; i < XMT_FILT_LEN; i++) xmt_signal[i] = 0.0;
+	qsk_signal = new double[QSK_DELAY_LEN];
+	for (int i = 0; i < QSK_DELAY_LEN; i++) qsk_signal[i] = 0.0;
+	cw_xmt_filter = new fftfilt( lwr, upr, 2*XMT_FILT_LEN);// transmit filter length
+//		FilterFFTLen);
+
 // bit filter based on 10 msec rise time of CW waveform
 	int bfv = (int)(samplerate * .010 / DEC_RATIO);
 	bitfilter = new Cmovavg(bfv);
@@ -387,15 +412,12 @@ void cw::reset_rx_filter()
 // Synchronize the dot, dash, end of element, end of character, and end
 // of word timings and ranges to new values of Morse speed, or receive tolerance.
 
-void cw::sync_parameters()
+void cw::sync_transmit_parameters()
 {
-	int lowerwpm, upperwpm, nusymbollen, nufsymlen;
-
-	int wpm = usedefaultWPM ? progdefaults.defCWspeed : progdefaults.CWspeed;
-	int fwpm = progdefaults.CWfarnsworth;
+	wpm = usedefaultWPM ? progdefaults.defCWspeed : progdefaults.CWspeed;
+	fwpm = progdefaults.CWfarnsworth;
 
 	cw_send_dot_length = DOT_MAGIC / progdefaults.CWspeed;
-
 	cw_send_dash_length = 3 * cw_send_dot_length;
 
 	nusymbollen = (int)round(samplerate * 1.2 / wpm);
@@ -404,13 +426,18 @@ void cw::sync_parameters()
 	if (symbollen != nusymbollen ||
 		nufsymlen != fsymlen ||
 		risetime  != progdefaults.CWrisetime ||
-		QSKshape  != progdefaults.QSKshape ) {
+		QSKshape  != progdefaults.QSKshape) {
 		risetime = progdefaults.CWrisetime;
 		QSKshape = progdefaults.QSKshape;
 		symbollen = nusymbollen;
 		fsymlen = nufsymlen;
 		makeshape();
 	}
+}
+
+void cw::sync_parameters()
+{
+	sync_transmit_parameters();
 
 // check if user changed the tracking or the cw default speed
 	if ((cwTrack != progdefaults.CWtrack) ||
@@ -875,21 +902,18 @@ double keyshape[KNUM];
 void cw::makeshape()
 {
 	for (int i = 0; i < KNUM; i++) keyshape[i] = 1.0;
-	knum = (int)(8 * risetime);
-
-	if (knum >= symbollen)
-		knum = symbollen - 1;
-
-	if (knum > KNUM)
-		knum = KNUM;
 
 	switch (QSKshape) {
 		case 1: // blackman
+			knum = (int)(8 * risetime);
+			if (knum >= symbollen) knum = symbollen;
 			for (int i = 0; i < knum; i++)
 				keyshape[i] = (0.42 - 0.50 * cos(M_PI * i/ knum) + 0.08 * cos(2 * M_PI * i / knum));
 			break;
-		case 0: // raised cosine (hanning)
+		case 0: // hanning
 		default:
+			knum = (int)(8 * risetime);
+			if (knum >= symbollen) knum = symbollen;
 			for (int i = 0; i < knum; i++)
 				keyshape[i] = 0.5 * (1.0 - cos (M_PI * i / knum));
 	}
@@ -928,6 +952,56 @@ inline double cw::qsknco()
 // character.
 //=======================================================================
 
+//void appendfile(double *left, double *right, size_t count)
+//{
+//	FILE *ofile = fopen("stereo.txt", "a");
+//	for (size_t i = 0; i < count; i++)
+//		fprintf(ofile,"%f,%f\n", left[i], right[i]);
+//	fclose(ofile);
+//}
+
+void cw::nb_filter(double *output, double *qsk, int len)
+{
+// fft implementation of 
+	if (nbfreq != tx_frequency ||
+		nbpf != progdefaults.CW_bpf) {
+
+		nbfreq = tx_frequency;
+		nbpf = progdefaults.CW_bpf;
+		lwr = nbfreq - nbpf/2.0;
+		upr = nbfreq + nbpf/2.0;
+		if (lwr < 50.0) lwr = 50.0;
+		if (upr > 3900.0) upr = 3900.0;
+		lwr /= samplerate;
+		upr /= samplerate;
+		cw_xmt_filter->create_filter(lwr, upr);
+	}
+	cmplx *zp;
+	int n = 0;
+	for (int i = 0; i < len; i++) {
+// n will be either 0 or XMT_FILT_LEN
+		qsk_signal[qsk_ptr] = qsk[i];
+		qsk_ptr++;
+		if (qsk_ptr == QSK_DELAY_LEN) qsk_ptr--;
+		if ((n = cw_xmt_filter->run(
+					cmplx(output[i], output[i]), 
+					&zp)) > 0) {
+			for (int k = 0; k < n; k++)
+				xmt_signal[k] = zp[k].real();
+
+//			appendfile(xmt_signal, qsk_signal, n);
+
+			if (progdefaults.QSK)
+				ModulateStereo(xmt_signal, qsk_signal, n);
+			else
+				ModulateXmtr(xmt_signal, n);
+			for (int k = 0; k < QSK_DELAY_LEN - n - 1; k++)
+				qsk_signal[k] = qsk_signal[k + n];
+			qsk_ptr -= n;
+		}
+	}
+}
+
 int q_carryover = 0, carryover = 0;
 
 void cw::send_symbol(int bits, int len)
@@ -943,6 +1017,9 @@ void cw::send_symbol(int bits, int len)
 	int symlen = 0;
 	float dsymlen = 0.0;
 	int currsym = bits & 1;
+	double qsk_amp = progdefaults.QSK ? 1.0 : 0.0;
+
+	sync_transmit_parameters();
 
 	acc_symbols += len;
 
@@ -994,7 +1071,7 @@ void cw::send_symbol(int bits, int len)
 		if (lastsym == 1) {
 			for (i = 0; i < keydown; i++, sample++) {
 				outbuf[sample] = nco(freq);
-				qskbuf[sample] = qsknco();
+				qskbuf[sample] = qsk_amp * qsknco();
 			}
 			duration = keydown;
 		} else {
@@ -1008,11 +1085,11 @@ void cw::send_symbol(int bits, int len)
 					outbuf[sample] = 0 * nco(freq);
 			sample = 0;
 			for (int i = 0; i < kpre; i++, sample++) {
-				qskbuf[sample] = qsknco();
+				qskbuf[sample] = qsk_amp * qsknco();
 			}
 			for (int i = 0; i < knum; i++, sample++) {
 				outbuf[sample] = nco(freq) * keyshape[i];
-				qskbuf[sample] = qsknco();
+				qskbuf[sample] = qsk_amp * qsknco();
 			}
 			duration = kpre + knum;
 		}
@@ -1035,7 +1112,7 @@ void cw::send_symbol(int bits, int len)
 			qsample = 0;
 			if (q_carryover) {
 				for (int i = 0; i < q_carryover; i++, qsample++) {
-					qskbuf[qsample] = qsknco();
+					qskbuf[qsample] = qsk_amp * qsknco();
 				}
 				while (qsample < duration)
 					qskbuf[qsample++] = 0 * qsknco();
@@ -1077,7 +1154,7 @@ void cw::send_symbol(int bits, int len)
 					q_carryover = kpost - duration;
 					break;
 				}
-				qskbuf[qsample] = qsknco();
+				qskbuf[qsample] = qsk_amp * qsknco();
 			}
 			while (qsample < duration)
 				qskbuf[qsample++] = 0 * qsknco();
@@ -1085,10 +1162,14 @@ void cw::send_symbol(int bits, int len)
 	}
 
 	if (duration > 0) {
-		if (progdefaults.QSK)
-			ModulateStereo(outbuf, qskbuf, duration);
-		else
-			ModulateXmtr(outbuf, duration);
+		if (progdefaults.CW_bpf_on)
+			nb_filter(outbuf, qskbuf, duration);
+		else {
+			if (progdefaults.QSK)
+				ModulateStereo(outbuf, qskbuf, duration);
+			else
+				ModulateXmtr(outbuf, duration);
+		}
 	}
 
 	lastsym = currsym;
@@ -1188,7 +1269,12 @@ int cw::tx_process()
 	c = get_tx_char();
 	if (c == GET_TX_CHAR_ETX || stopflag) {
 		stopflag = false;
-			return -1;
+		if (progdefaults.CW_bpf_on) { // flush the transmit bandpass filter
+			int n = cw_xmt_filter->flush_size();
+			for (int i = 0; i < n; i++) outbuf[i] = 0;
+			nb_filter(outbuf, outbuf, n);
+		}
+		return -1;
 	}
 	acc_symbols = 0;
 	send_ch(c);
