@@ -115,27 +115,35 @@ enum {
 	MODE_PSK125,
 	MODE_PSK250,
 	MODE_PSK500,
+	MODE_PSK1000,
+
+	MODE_12X_PSK125,
+	MODE_6X_PSK250,
+	MODE_2X_PSK500,
+	MODE_4X_PSK500,
+	MODE_2X_PSK800,
+	MODE_2X_PSK1000,
+
+	MODE_PSK_FIRST = MODE_PSK31,
+	MODE_PSK_LAST = MODE_2X_PSK1000,
+
 	MODE_QPSK31,
 	MODE_QPSK63,
 	MODE_QPSK125,
 	MODE_QPSK250,
 	MODE_QPSK500,
 
+	MODE_QPSK_FIRST = MODE_QPSK31,
+	MODE_QPSK_LAST = MODE_QPSK500,
+
 	MODE_8PSK125,
 	MODE_8PSK250,
 	MODE_8PSK500,
 	MODE_8PSK1000,
-//	MODE_8PSK2000,
+	MODE_8PSK1200,
+	MODE_8PSK1333,
 	MODE_8PSK_FIRST = MODE_8PSK125,
-	MODE_8PSK_LAST = MODE_8PSK1000,
-
-	MODE_PSK125R,
-	MODE_PSK250R,
-	MODE_PSK500R,
-	MODE_PSK1000,
-	MODE_PSK1000R,
-	MODE_PSK_FIRST = MODE_PSK31,
-	MODE_PSK_LAST = MODE_PSK1000R,
+	MODE_8PSK_LAST = MODE_8PSK1333,
 
 	MODE_OLIVIA,
 	MODE_OLIVIA_4_250,
@@ -147,6 +155,8 @@ enum {
 	MODE_OLIVIA_16_1000,
 	MODE_OLIVIA_32_1000,
 	MODE_OLIVIA_64_2000,
+	MODE_OLIVIA_FIRST = MODE_OLIVIA,
+	MODE_OLIVIA_LAST = MODE_OLIVIA_64_2000,
 
 	MODE_RTTY,
 
@@ -175,6 +185,11 @@ enum {
 //	MODE_PACKET,
 // high speed && multiple carrier modes
 
+	MODE_PSK125R,
+	MODE_PSK250R,
+	MODE_PSK500R,
+	MODE_PSK1000R,
+
 	MODE_4X_PSK63R,
 	MODE_5X_PSK63R,
 	MODE_10X_PSK63R,
@@ -184,31 +199,25 @@ enum {
 	MODE_4X_PSK125R,
 	MODE_5X_PSK125R,
 	MODE_10X_PSK125R,
-	MODE_12X_PSK125,
 	MODE_12X_PSK125R,
 	MODE_16X_PSK125R,
 
-	MODE_6X_PSK250,
-
 	MODE_2X_PSK250R,
 	MODE_3X_PSK250R,
 	MODE_5X_PSK250R,
 	MODE_6X_PSK250R,
 	MODE_7X_PSK250R,
 
-	MODE_2X_PSK500,
-	MODE_4X_PSK500,
-
 	MODE_2X_PSK500R,
 	MODE_3X_PSK500R,
 	MODE_4X_PSK500R,
 
-	MODE_2X_PSK800,
 	MODE_2X_PSK800R,
-
-	MODE_2X_PSK1000,
 	MODE_2X_PSK1000R,
 
+	MODE_PSKR_FIRST = MODE_PSK125R,
+	MODE_PSKR_LAST = MODE_2X_PSK1000R,
+
 	MODE_SSB,
 	MODE_WWV,
 	MODE_ANALYSIS,
