@@ -207,6 +207,12 @@ public:
 public:
 	virtual void	refresh_scope() {}
 
+// for multi-channel modems
+public:
+	virtual void clear_viewer() {}
+	virtual void clear_ch(int n) {}
+	virtual int  viewer_get_freq(int n) {return 0; }
+
 // for noise tests
 private:
 	void	add_noise(double *, int);
@@ -293,7 +299,8 @@ extern modem *_8psk125_modem;
 extern modem *_8psk250_modem;
 extern modem *_8psk500_modem;
 extern modem *_8psk1000_modem;
-extern modem *_8psk2000_modem;
+extern modem *_8psk1200_modem;
+extern modem *_8psk1333_modem;
 
 extern modem *psk125r_modem;
 extern modem *psk250r_modem;
