@@ -39,7 +39,6 @@
 #include "mfskvaricode.h"
 
 //=====================================================================
-//#define	PskSampleRate	(8000)
 #define PipeLen			(64)
 
 #define SNTHRESHOLD 6.0
@@ -56,7 +55,6 @@ class psk : public modem {
 private:
 // tx & rx
 	int			symbollen;
-	int			PskSampleRate;
 	int			symbits;
 	bool			_qpsk;
 	bool			_pskr;
@@ -189,6 +187,14 @@ public:
 	int tx_process();
 	void searchDown();
 	void searchUp();
+
+	void clear_viewer() { pskviewer->clear(); }
+	void clear_ch(int n) { pskviewer->clearch(n); }
+	int  viewer_get_freq(int n) {
+		if (pskviewer) pskviewer->get_freq(n);
+		return 0;
+	}
+
 };
 
 #endif
