@@ -137,6 +137,7 @@ struct status {
 	bool	useUART;
 	bool	PreferXhairScope;
 	bool	PseudoFSK;
+	bool	shaped_rtty;
 	bool	UOSrx;
 	bool	UOStx;
 // end Contestia, Olivia, RTTY state values
@@ -159,6 +160,8 @@ struct status {
 
 	std::string	browser_search;
 
+	bool	meters;
+
 	bool	bLastStateRead;
 
 	void initLastState();
