@@ -82,14 +82,12 @@ FIELD fields[] = {
 	{ITUZ,           "ITUZ",         &btnSelectITUZ},      // ITU zone
 	{CONT,           "CONT",         &btnSelectCONT},      // contacted stations continent
 
-	{MYXCHG,         "MYXCHG",       &btnSelectMyXchg},    // contest exchange sent
-	{XCHG1,          "XCHG1",        &btnSelectXchgIn},    // contest exchange #1 / free1 in xlog
-
-	{MYXCHG,         "STX_STRING",   &btnSelectMyXchg},    // contest exchange sent
-	{XCHG1,          "SRX_STRING",   &btnSelectXchgIn},    // contest exchange #1 / free1 in xlog
-
 	{SRX,            "SRX",          &btnSelectSerialIN},  // received serial number for a contest QSO
 	{STX,            "STX",          &btnSelectSerialOUT}, // QSO transmitted serial number
+
+	{XCHG1,          "SRX_STRING",   &btnSelectXchgIn},    // contest exchange #1 / free1 in xlog
+	{MYXCHG,         "STX_STRING",   &btnSelectMyXchg},    // contest exchange sent
+
 	{TX_PWR,         "TX_PWR",       &btnSelectTX_pwr},    // power transmitted by this station
 	{NUMFIELDS,      "",             NULL}
 };
@@ -159,7 +157,9 @@ static inline int findfield( char *p )
 			*p1 = 0;
 			pos = strcasestr(fastlookup, p);
 			*p1 = ':';
-			if (pos) return fields[(pos - fastlookup) / maxlen].type;
+			if (pos) {
+				return fields[(pos - fastlookup) / maxlen].type;
+			}
 		}
 	}
 	return -2;		//search key not found
@@ -215,16 +215,11 @@ void cAdifIO::do_readfile(const char *fname, cQsoDb *db)
 	char *buff;
 	int found;
 
-LOG_INFO("Reading %s", fname);
-
 // open the adif file
 	FILE *adiFile = fopen (fname, "r");
 
-	if (adiFile == NULL) {
-LOG_INFO("Cannot open %s", fname);
+	if (adiFile == NULL)
 		return;
-	}
-
 // determine its size for buffer creation
 	fseek (adiFile, 0, SEEK_END);
 	filesize = ftell (adiFile);
@@ -291,6 +286,7 @@ LOG_INFO("Cannot open %s", fname);
 	}
 
 	p2 = strchr(p1,'<'); // find first ADIF specifier
+//	adifqso.clearRec();
 
 	adifqso = 0;
 	while (p2) {
@@ -413,10 +409,8 @@ void cAdifIO::readFile (const char *fname, cQsoDb *db)
 {
 	ENSURE_THREAD(FLMAIN_TID);
 
-	if (!ADIF_RW_thread) {
+	if (!ADIF_RW_thread)
 		ADIF_RW_init();
-		MilliSleep(50);
-	}
 
 	pthread_mutex_lock(&ADIF_RW_mutex);
 
@@ -488,10 +482,7 @@ void cAdifIO::do_writelog()
 
 	if (!adiFile) {
 		LOG_ERROR("Cannot write to %s", adif_file_name.c_str());
-		if (wrdb) {
-			delete wrdb;
-			wrdb = 0;
-		}
+		if (wrdb) delete wrdb;
 		return;
 	}
 	LOG_INFO("Writing %s", adif_file_name.c_str());
@@ -536,10 +527,7 @@ void cAdifIO::do_writelog()
 
 	fclose (adiFile);
 
-	if (wrdb) {
-		delete wrdb;
-		wrdb = 0;
-	}
+	if (wrdb) delete wrdb;
 
 #ifdef _POSIX_MONOTONIC_CLOCK
 	clock_gettime(CLOCK_MONOTONIC, &t1);
@@ -609,13 +597,11 @@ static void ADIF_RW_init()
 
 	if (ADIF_RW_thread)
 		return;
-LOG_INFO("%s","Starting logbook r/w thread");
-
 	ADIF_RW_thread = new pthread_t;
 	ADIF_RW_EXIT = false;
 	if (pthread_create(ADIF_RW_thread, NULL, ADIF_RW_loop, NULL) != 0) {
 		LOG_PERROR("pthread_create");
 		return;
 	}
-//	MilliSleep(50); // increased from 10 for Win7 testing
+	MilliSleep(10);
 }
