@@ -3,7 +3,7 @@
 //
 // Copyright (C) 2006-2009
 //		Dave Freese, W1HKJ
-//		Remi Chateaunaeu, 2011
+//		Remi Chateauneu, 2011
 //
 // This file is part of fldigi.
 //
@@ -22,30 +22,20 @@
 // ----------------------------------------------------------------------------
 
 #include <config.h>
-#include <unistd.h>
-
-#include <cstdio>
-#include <cstdlib>
-#include <unistd.h>
-#include <string>
 #include <fstream>
+#include <stdlib.h>
+#include <ctype.h>
+#include <string.h>
 #include <iostream>
-#include <queue>
-
-#include <time.h>
-
 #include "qso_db.h"
 #include "field_def.h"
 #include "globals.h"
 #include "timeops.h"
 
-// following needed for localtime_r
-#include <pthread.h>
+#include "pthread.h"
 
 using namespace std;
 
-// class cQsoRec
-
 static int compby = COMPDATE;
 static bool date_off = true;
 
