@@ -19,7 +19,7 @@
 // You should have received a copy of the GNU General Public License
 // along with fldigi.  If not, see <http://www.gnu.org/licenses/>.
 //
-// Please report all bugs and problems to fldigi-devel@lists.berlios.de.
+// Please report all bugs and problems to fldigi-devel@lists.sourceforge.net.
 // ----------------------------------------------------------------------------
 
 #include <config.h>
@@ -267,6 +267,26 @@ static void auto_start()
 		start_process(progdefaults.auto_prog3_pathname);
 }
 
+void toggle_io_port_selection(int io_mode)
+{
+	switch(io_mode) {
+		case ARQ_IO:
+			btnEnable_kiss->do_callback();
+			btnEnable_arq->do_callback();
+			progdefaults.changed = false;
+			break;
+
+		case KISS_IO:
+			btnEnable_arq->do_callback();
+			btnEnable_kiss->do_callback();
+			progdefaults.changed = false;
+			break;
+
+		default:
+			LOG_INFO("Unknown data io mode");
+	}
+}
+
 // these functions are all started after Fl::run() is executing
 void delayed_startup(void *)
 {
@@ -283,7 +303,9 @@ void delayed_startup(void *)
 	data_io_enabled = DISABLED_IO;
 	arq_init();
 	kiss_init();
-	data_io_enabled = progdefaults.data_io_enabled;
+	data_io_enabled = progStatus.data_io_enabled;
+
+	toggle_io_port_selection(data_io_enabled);
 
 	notify_start();
 
@@ -1218,17 +1240,17 @@ int parse_args(int argc, char **argv, int& idx)
 			Fl::set_font(FL_HELVETICA, optarg);
 			break;
 
-		case OPT_WFALL_HEIGHT:
-			progdefaults.wfheight = strtol(optarg, NULL, 10);
-			break;
+//		case OPT_WFALL_HEIGHT:
+//			progdefaults.wfheight = strtol(optarg, NULL, 10);
+//			break;
 
-		case OPT_WINDOW_WIDTH:
-			WNOM = strtol(optarg, NULL, 10);
-			break;
+//		case OPT_WINDOW_WIDTH:
+//			WNOM = strtol(optarg, NULL, 10);
+//			break;
 
-		case OPT_WINDOW_HEIGHT:
-			HNOM = strtol(optarg, NULL, 10);
-			break;
+//		case OPT_WINDOW_HEIGHT:
+//			HNOM = strtol(optarg, NULL, 10);
+//			break;
 
 #if USE_PORTAUDIO
 		case OPT_FRAMES_PER_BUFFER:
