@@ -104,8 +104,8 @@ status progStatus = {
 	false,				// bool VIEWERvisible
 	100,				// int		tile_x
 	200,				// int		tile_w;
-	50,					// int		tile_y;
-	100,				// int		tile_h;
+	90,					// int		tile_y;
+	150,				// int		tile_h;
 	false,				// bool LOGenabled
 	5.0,				// double sldrSquelchValue
 	5.0,				// double sldrPwrSquelchValue
@@ -174,6 +174,7 @@ status progStatus = {
 	progdefaults.useUART,
 	progdefaults.PreferXhairScope,
 	progdefaults.PseudoFSK,
+	true,						// bool shaped_rtty
 	progdefaults.UOSrx,
 	progdefaults.UOStx,
     DEFAULT_XMLPRC_IP_ADDRESS,
@@ -194,6 +195,8 @@ status progStatus = {
 
 	"CQ",				// string browser_search;
 
+	false,				// meters
+
 	false				// bool bLastStateRead;
 };
 
@@ -426,6 +429,7 @@ if (!bWF_only) {
 	spref.set("rtty_useUART", useUART);
 	spref.set("preferxhairscope", PreferXhairScope);
 	spref.set("psaudofsk", PseudoFSK);
+	spref.set("shaped_rtty", shaped_rtty);
 	spref.set("uosrx", UOSrx);
 	spref.set("uostx", UOStx);
 
@@ -456,6 +460,8 @@ if (!bWF_only) {
 	spref.set("csma_enabled", csma_enabled);
 	spref.set("browser_search", browser_search.c_str());
 
+	spref.set("meters", meters);
+
 //	spref.set("xml_logbook", xml_logbook);
 }
 
@@ -520,9 +526,21 @@ void status::loadLastState()
 	noCATwidth = strbuff;
 
 	spref.get("main_x", mainX, mainX);
+	if (mainX > Fl::w())
+		mainX = 0;
+
 	spref.get("main_y", mainY, mainY);
+	if (mainY > Fl::h())
+		mainY = 0;
+
 	spref.get("main_w", mainW, mainW);
+	if (mainW < WMIN) mainW = WMIN;
+	if (mainW > Fl::w()) mainW = Fl::w();
+
 	spref.get("main_h", mainH, mainH);
+	if (mainH < HMIN) mainH = HMIN;
+	if (mainH > Fl::w()) mainH = Fl::h();
+
 	spref.get("wf_ui", i, WF_UI); WF_UI = i;
 	spref.get("riglog_ui", i, Rig_Log_UI); Rig_Log_UI = i;
 	spref.get("rigcontest_ui", i, Rig_Contest_UI); Rig_Contest_UI = i;
@@ -609,6 +627,7 @@ void status::loadLastState()
 	spref.get("rtty_useUART", i, useUART); useUART = i;
 	spref.get("preferxhairscope", i, PreferXhairScope); PreferXhairScope = i;
 	spref.get("psaudofsk", i, PseudoFSK); PseudoFSK = i;
+	spref.get("shaped_rtty", i, shaped_rtty); shaped_rtty = i;
 	spref.get("uosrx", i, UOSrx); UOSrx = i;
 	spref.get("uostx", i, UOStx); UOStx = i;
 
@@ -663,6 +682,8 @@ void status::loadLastState()
 	browser_search = strbuff;
 	seek_re.recompile(browser_search.c_str());
 
+	spref.get("meters",  i, meters); meters = i;
+
 //	spref.get("xml_logbook", i, xml_logbook); xml_logbook = i;
 }
 
@@ -696,9 +717,7 @@ void status::initLastState()
 		btnPreferXhairScope->value(progdefaults.PreferXhairScope = PreferXhairScope);
 
 		if (mvsquelch) {
-
-printf("init rtty squelch %f\n", VIEWER_rttysquelch);
-
+//printf("init rtty squelch %f\n", VIEWER_rttysquelch);
 			mvsquelch->range(-12.0, 6.0);
 			mvsquelch->value(VIEWER_rttysquelch);
 		}
@@ -747,20 +766,31 @@ printf("init rtty squelch %f\n", VIEWER_rttysquelch);
 	wf->setAmpSpan();
 
 	btnAFC->value(afconoff);
-	btnSQL->value(sqlonoff);
-	btnPSQL->value(pwrsqlonoff);
 
 	if(override_data_io_enabled != DISABLED_IO) {
 		data_io_enabled = override_data_io_enabled;
-		if(data_io_enabled == ARQ_IO) {
-			btnEnable_arq->value(true);
-			btnEnable_kiss->value(false);
-		} else {
-			btnEnable_arq->value(false);
-			btnEnable_kiss->value(true);
-		}
+		progdefaults.data_io_enabled = data_io_enabled;
+		progStatus.data_io_enabled = data_io_enabled;
 	}
 
+	if(progStatus.data_io_enabled == KISS_IO) {
+		data_io_enabled = KISS_IO;
+		progdefaults.data_io_enabled = KISS_IO;
+	} else {
+		data_io_enabled = ARQ_IO;
+		progdefaults.data_io_enabled = ARQ_IO;
+		progStatus.data_io_enabled = ARQ_IO;
+		pwrsqlonoff = false;
+	}
+
+	btnSQL->value(sqlonoff);
+	btnPSQL->value(pwrsqlonoff);
+
+	if(pwrsqlonoff)
+		sldrSquelch->value(sldrPwrSquelchValue);
+	else
+		sldrSquelch->value(sldrSquelchValue);
+
 	if(arq_address_override_flag) {
 		if(!override_arq_address.empty())
 			arq_address = progdefaults.arq_address = override_arq_address;
@@ -808,22 +838,8 @@ printf("init rtty squelch %f\n", VIEWER_rttysquelch);
 	cntKPSQLAttenuation->value(kpsql_attenuation);
 	progdefaults.kpsql_attenuation = kpsql_attenuation;
 
-	if(pwrsqlonoff)
-		sldrSquelch->value(sldrPwrSquelchValue);
-	else
-		sldrSquelch->value(sldrSquelchValue);
-
-	if (mainX > Fl::w())
-		mainX = 0;
-	if (mainY > Fl::h())
-		mainY = 0;
-	if (mainW < WMIN) mainW = WMIN;
-	if (mainW > Fl::w()) mainW = Fl::w();
-	if (mainH < HMIN) mainH = HMIN;
-	if (mainH > Fl::w()) mainH = Fl::h();
-
-	if (bWF_only) 
-		fl_digi_main->resize(mainX, mainY, mainW, Hmenu + Hwfall + Hstatus);// + 4);
+	if (bWF_only)
+		fl_digi_main->resize(mainX, mainY, mainW, Hmenu + Hwfall + Hstatus);
 	else {
 		fl_digi_main->resize(mainX, mainY, mainW, mainH);
 
