@@ -429,7 +429,9 @@ void qso_addFreq()
 void setTitle()
 {
 	if (windowTitle.empty()) return;
-	main_window_title.assign("fldigi / ").append(windowTitle);
+	size_t p = main_window_title.find(" / ");
+	if (p != string::npos) main_window_title.erase(p);
+	main_window_title.append(" / ").append(windowTitle);
 	update_main_title();
 }
 
