@@ -58,17 +58,6 @@ static void init_oss(void)
 		progdefaults.OSSdevice = gbuf.gl_pathv[0];
 	menuOSSDev->value(progdefaults.OSSdevice.c_str());
 	globfree(&gbuf);
-
-	glob("/dev/mixer*", 0, NULL, &gbuf);
-	for (size_t i = 0; i < gbuf.gl_pathc; i++)
-		menuMix->add(gbuf.gl_pathv[i]);
-	if (progdefaults.MXdevice.length() == 0 && gbuf.gl_pathc)
-		progdefaults.MXdevice = gbuf.gl_pathv[0];
-	globfree(&gbuf);
-	menuMix->value(progdefaults.MXdevice.c_str());
-#else
-	progdefaults.EnableMixer = false;
-	tabMixer->parent()->remove(*tabMixer);
 #endif // USE_OSS
 }
 
@@ -310,46 +299,37 @@ static void sound_init_options(void)
 		}
 	}
 
-	valPCMvolume->value(progdefaults.PCMvolume);
-	btnMicIn->value(progdefaults.MicIn);
-	btnLineIn->value(progdefaults.LineIn);
-
 	menuOSSDev->value(progdefaults.OSSdevice.c_str());
 	inpPulseServer->value(progdefaults.PulseServer.c_str());
 
-	btnMixer->value(progdefaults.EnableMixer);
-	menuMix->value(progdefaults.MXdevice.c_str());
-
-	enableMixer(progdefaults.EnableMixer);
-
 	char sr[6+1];
 	if (progdefaults.in_sample_rate == SAMPLE_RATE_UNSET &&
 		(progdefaults.in_sample_rate = progdefaults.sample_rate) == SAMPLE_RATE_UNSET)
 		progdefaults.in_sample_rate = SAMPLE_RATE_NATIVE;
-	else if (progdefaults.in_sample_rate > SAMPLE_RATE_OTHER)
-		snprintf(sr, sizeof(sr), "%d", progdefaults.in_sample_rate);
-	if (progdefaults.in_sample_rate <= SAMPLE_RATE_NATIVE)
+	else if (progdefaults.in_sample_rate < SAMPLE_RATE_OTHER)
 		menuInSampleRate->index(progdefaults.in_sample_rate);
-	else
-		for (int i = 1; i <= menuInSampleRate->lsize(); i++) {
+	else {
+		snprintf(sr, sizeof(sr), "%d", progdefaults.in_sample_rate);
+		for (int i = SAMPLE_RATE_NATIVE + 1; i < menuInSampleRate->lsize(); i++) {
 			menuInSampleRate->index(i);
 			if (strstr(menuInSampleRate->value(), sr))
 				break;
 		}
+	}
 
 	if (progdefaults.out_sample_rate == SAMPLE_RATE_UNSET &&
 		(progdefaults.out_sample_rate = progdefaults.sample_rate) == SAMPLE_RATE_UNSET)
 		progdefaults.out_sample_rate = SAMPLE_RATE_NATIVE;
-	else if (progdefaults.out_sample_rate > SAMPLE_RATE_OTHER)
-		snprintf(sr, sizeof(sr), "%d", progdefaults.out_sample_rate);
-	if (progdefaults.out_sample_rate <= SAMPLE_RATE_NATIVE)
+	else if (progdefaults.out_sample_rate < SAMPLE_RATE_OTHER)
 		menuOutSampleRate->index(progdefaults.out_sample_rate);
-	else
-		for (int i = 1; i <= menuOutSampleRate->lsize(); i++) {
+	else {
+		snprintf(sr, sizeof(sr), "%d", progdefaults.out_sample_rate);
+		for (int i = SAMPLE_RATE_NATIVE + 1; i < menuOutSampleRate->lsize(); i++) {
 			menuOutSampleRate->index(i);
 			if (strstr(menuOutSampleRate->value(), sr))
 				break;
 		}
+	}
 
 	cntRxRateCorr->value(progdefaults.RX_corr);
 	cntTxRateCorr->value(progdefaults.TX_corr);
@@ -435,7 +415,6 @@ void sound_init(void)
 
 	sound_update(progdefaults.btnAudioIOis);
 
-	resetMixerControls();
 }
 
 void sound_close(void)
@@ -500,7 +479,7 @@ void sound_update(unsigned idx)
 					break;
 				}
 
-				for (int j = 1; j < listbox[i]->lsize(); j++) {
+				for (int j = 0; j < listbox[i]->lsize(); j++) {
 					listbox[i]->index(j);
 					if (strstr(listbox[i]->value(), label))
 						break;
