@@ -140,11 +140,9 @@ void Digiscope::data(double *data, int len, bool scale)
 			max = MAX(max, _buf[i]);
 			min = MIN(min, _buf[i]);
 		}
+		if (max == min) max *= 1.001;
 		for (int i = 0; i < _len; i++)
-			if (_buf[i] > 0.001) // threshold
-				_buf[i] = (_buf[i] - min) / (max - min);
-			else
-				_buf[i] = 0.0;
+			_buf[i] = (_buf[i] - min) / (max - min);
 	}
 	REQ_DROP(&Digiscope::redraw, this);
 	FL_UNLOCK_D();
@@ -388,12 +386,19 @@ void Digiscope::draw_rtty()
 		fl_vertex( 0.0, 0.1);
 		fl_vertex( 1.0, 0.1);
 	fl_end_line();
+	fl_color(FL_WHITE);
+	fl_begin_line();
+		fl_vertex( 0.0, 0.5);
+		fl_vertex( 1.0, 0.5);
+	fl_end_line();
 	fl_color(FL_GREEN);
 	fl_begin_line();
+	double value = 0.0;
 	for (int i = 0; i < npts; i++) {
-		np = i * _len / npts;
-		np = np < MAX_LEN ? np : MAX_LEN - 1;
-		fl_vertex( (double)i / npts, 0.5 + 0.75 * _buf[np] );
+		np = round(1.0 * i * _len / npts);
+		if (np >= MAX_LEN) np = MAX_LEN - 1;
+		value = _buf[np];
+		fl_vertex( 1.0 * i / (npts - 1), 0.5 + 0.75 * value );
 	}
 	fl_end_line();
 	fl_pop_matrix();
